// A mathematical game
// Copyright (C) 2004 by Christian von Schultz <schultz@linux.nu>

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef ROOMLIST_H
#define ROOMLIST_H

#include <wx/wxexpr.h>
#include <new>

#include <config.h>
#include "checksetup.h"

#include "exceptions.h"

class RoomList
{
public:
  RoomList() throw(Exception);
  ~RoomList() throw();

  const wxExpr* GetExpr(const wxString &functor) const throw(NullException);

  void OpenFile(const wxString &filename) throw(Exception);

private:
  wxExprDatabase *m_db;
  wxExprDatabase *m_open_file;

#if __WXDEBUG__
private:
  RoomList(const RoomList &rl) {};
#endif

};

#endif // ROOMLIST_H

// 
// Local Variables:
// mode: c++
// End:
